aboutsummaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2024-01-10 14:20:44 +0100
committerChristian Grothoff <christian@grothoff.org>2024-01-10 14:20:50 +0100
commit68ced6e31a9d247bf18f22754c0bd3619ca9f726 (patch)
tree447650aba8d5f45189fcbf22012c154e70b0b9fa /src/include
parente0cc5c9caf3953ee8409fad854ab894fd1a521e7 (diff)
downloadexchange-68ced6e31a9d247bf18f22754c0bd3619ca9f726.tar.xz
add TALER_PQ_array_of_amount_currency
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_pq_lib.h17
1 files changed, 16 insertions, 1 deletions
diff --git a/src/include/taler_pq_lib.h b/src/include/taler_pq_lib.h
index a529b4302..cf9f7c02f 100644
--- a/src/include/taler_pq_lib.h
+++ b/src/include/taler_pq_lib.h
@@ -177,8 +177,9 @@ TALER_PQ_query_param_array_hash_code (
const struct GNUNET_HashCode *hashes,
struct GNUNET_PQ_Context *db);
+
/**
* Generate query parameter for an array of mounts
*
* @param num of elements in @e amounts
* @param amounts continuous array of amounts
@@ -192,6 +193,20 @@ TALER_PQ_query_param_array_amount (
/**
+ * Generate query parameter for an array of amounts
+ *
+ * @param num of elements in @e amounts
+ * @param amounts continuous array of amounts
+ * @param db context for db-connection, needed for OID-lookup
+ */
+struct GNUNET_PQ_QueryParam
+TALER_PQ_query_param_array_amount_with_currency (
+ size_t num,
+ const struct TALER_Amount *amounts,
+ struct GNUNET_PQ_Context *db);
+
+
+/**
* Generate query parameter for a blind sign public key of variable size.
*
* @param public_key pointer to the query parameter to pass
@@ -177,8 +177,9 @@ TALER_PQ_query_param_array_hash_code (
/**
- * Generate query parameter for an array of mounts
+ * Generate query parameter for an array of amounts
*
* @param num of elements in @e amounts